---
name: Bug Report
about: "Report any bugs, errors, problems, etc."
title: "[Bug] Short Description of Erroneous/Problematic Behavior"
labels: bug
assignees: ""

---

## Description of Issue
Please put a longer description of the bug/issue/problem you are encountering here, as well as anything else you think might be relevant or helpful to reproduce the issue.

## Additional Information as Applicable

#### Python Version
Python 3.x.x

#### Operating System/Environment
macOS/Windows/Linux/Docker/etc.

#### Other
Any other setup/environment/configuration information you might deem potentially relevant.
